@@ -8,6 +8,7 @@
 #include "selectwindows/whitch.h"
 #include "selectwindows/wmid.h"
 #include "selectwindows/wstop.h"
+#include "selectwindows/wlash.h"
 
 
 class About;
@@ -55,6 +56,8 @@ private slots:
 
     void on_pushButtonStop_pressed();
 
+    void on_pushButtonLash_pressed();
+
     void on_actionAbout_triggered();
 
     void on_actionHelp_triggered();
